@@ -4,10 +4,10 @@
 #   Distributed under MIT License
 #
 
-__version__ = 1.0
+__version__ = 1.1
 
 from .src.Braid import BraidArrangementIgusa
 from .src.Constructors import CoxeterArrangement, LinialArrangement, ShiArrangement, CatalanArrangement, DirectSum, PolynomialToArrangement, ResonanceArrangement
 from .src.LatticeFlats import LatticeOfFlats
-from .src.GenFunctions import FlagHilbertPoincareSeries, IgusaZetaFunction, CombinatorialSkeleton, AnalyticZetaFunction, AtomZetaFunction, TopologicalZetaFunction
+from .src.GenFunctions import FlagHilbertPoincareSeries, IgusaZetaFunction, CoarseFlagHPSeries, AnalyticZetaFunction, AtomZetaFunction, TopologicalZetaFunction
 from .src.Database import internal_database
\ No newline at end of file
